| auditParsers | R Documentation |
parseRecord on every record of an owner.Iterates a record metadata subset for owner, calls parseRecord per
unique (EventID, StationID), catches errors, and returns a status
table.
auditParsers(.x, owner, path)
.x |
record metadata |
owner |
one OwnerID string. |
path |
Absolute path to the records root passed through to
|
data.table(OwnerID, EventID, StationID, status, reason).
root <- file.path(tempdir(), "gmsp-auditparsers-example")
unlink(root, recursive = TRUE)
raw <- file.path(root, "ESM", "E1", "S1", "raw.owner")
dir.create(raw, recursive = TRUE)
writeLines(c("0 1", "0.01 2", "0.02 3"), file.path(raw, "N_acc.txt"))
writeLines(c("0 2", "0.01 3", "0.02 4"), file.path(raw, "E_acc.txt"))
writeLines(c("0 0", "0.01 1", "0.02 0"), file.path(raw, "Z_acc.txt"))
rows <- data.table::data.table(
OwnerID = "ESM", EventID = "E1", StationID = "S1",
FileID = c("N_acc.txt", "E_acc.txt", "Z_acc.txt")
)
auditParsers(rows, owner = "ESM", path = root)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.